/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration FT90x :
    
    MCU             : FT900
    Dev. Board      : EasyFT90x v7 
    SW              : mikroC PRO for FT900x v2.2.1

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level 08-15 to VCC, and GPIO 08-15 pull down GP08 and GP12, 
    speed is controlled by pressing GP08 and direction is changed by pressing GP12.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at GPIO_PIN1_bit;

uint16_t const maxPwmDuty = 5000;
uint16_t currentDuty = 0;
uint8_t oldstate = 0;

void systemInit()
{
    GPIO_Digital_Output( &GPIO_PORT_00_07, _GPIO_PINMASK_1 );
    currentDuty= PWM_Init(5000);
    PWM_ConfigChannel(currentDuty,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0);
    PWM_EnableOutput();
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&GPIO_PORT_08_15, 0, 1, 1))
    {
        currentDuty++;
        PWM_ConfigChannel(currentDuty,  _PWM_INIT_STATE_1, _PWM_CHANNEL_0);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&GPIO_PORT_08_15, 4, 1, 1)) 
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&GPIO_PORT_08_15, 4, 1, 0)) 
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0;   
    }                               
}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
    	Brushless_2_Task();
    }
}
